@@ -70,11 +70,16 @@ class Workflow(object):
         description="The AnADAMA2 workflow log.")
     
     @classmethod
-    def path(cls, name, main_folder="", none_if_not_found=None, error_if_not_found=None, **keywords):
+    def path(cls, name, main_folder="", none_if_not_found=None, error_if_not_found=None, search_for_file=False, **keywords):
         merged_keywords = copy.copy(keywords)
         merged_keywords.update(cls.file_info[name].get_path_keywords())
         file_path=name_files(folder=main_folder, **merged_keywords)
 
+        # if the file is not found, then look in the input folder
+        if not os.path.isfile(file_path) and search_for_file:
+            file_name = cls.filename(name)
+            file_path=os.path.join(main_folder, file_name)
+
         # if set, error if the file does not exist
         if error_if_not_found and not os.path.isfile(file_path):
             message="\nERROR: Unable to find file: "+file_path
@@ -86,7 +91,7 @@ class Workflow(object):
         # if set, check if the file exists, if not return None
         if none_if_not_found and not os.path.isfile(file_path):
                 file_path = None
-            
+           
         return file_path
     
     @classmethod
@@ -97,6 +102,15 @@ class Workflow(object):
             desc=""
             
         return desc
+
+    @classmethod
+    def filename(cls, name):
+        try: 
+            fname=cls.file_info[name].keywords["names"]
+        except (KeyError, AttributeError):
+            fname=""
+
+        return fname
     
     @classmethod
     def list_file_path_description(cls,folder,input_files):
@@ -108,6 +122,16 @@ class Workflow(object):
             
         return desc
 
+    @classmethod
+    def list_file_description(cls,input_files):
+        """ List the file names and descriptions in a format to be used in an argument help description """
+        
+        desc=""
+        for required in input_files:
+            desc+="\n".join(["* "+cls.filename(name)+ " ( " + required + " )\n-- "+cls.description(name)+"\n\n" for name in input_files[required]])+"\n"
+            
+        return desc
+
 class ShotGun(Workflow):
     """ A collection of information of folders/files created by the shotgun tasks """
     
@@ -129,64 +153,67 @@ class ShotGun(Workflow):
             "reference database continuing until all databases have been run."))
 
     # set the taxonomy file names
-    file_info["taxonomic_profile"]=FileInfo("metaphlan2_taxonomic_profiles.tsv",subfolder=os.path.join("metaphlan2","merged"),
+    file_info["taxonomic_profile"]=FileInfo("metaphlan_taxonomic_profiles.tsv",subfolder=os.path.join("metaphlan","merged"),
         description=("A tab-delimited file with samples as columns and relative abundance as rows.",
-            "This file contains the merged taxonomic profiles computed by MetaPhlAn2 for all samples."))
-    file_info["species_counts"]=FileInfo("metaphlan2_species_counts_table.tsv",subfolder=os.path.join("metaphlan2","merged"),
+            "This file contains the merged taxonomic profiles computed by MetaPhlAn for all samples."))
+    file_info["species_counts"]=FileInfo("metaphlan_species_counts_table.tsv",subfolder=os.path.join("metaphlan","merged"),
         description=("A tab-delimited file with samples as rows and counts as columns.",
             "This file contains the counts of total species for each sample using the ",
-            "species identified by MetaPhlAn2."))
+            "species identified by MetaPhlAn."))
     
     # set the merged feature file names
-    file_info["genefamilies"]=FileInfo("genefamilies.tsv",subfolder=os.path.join("humann2","merged"),
+    file_info["genefamilies"]=FileInfo("genefamilies.tsv",subfolder=os.path.join("humann","merged"),
         description=("A tab-delimited file with samples as columns and gene families ",
             "as rows. This file is a merged set of gene families for all samples ",
-            "computed by HUMAnN2. This file contains stratified counts as RPKs."))
-    file_info["ecs"]=FileInfo("ecs.tsv", subfolder=os.path.join("humann2","merged"),
+            "computed by HUMAnN. This file contains stratified counts as RPKs."))
+    file_info["ecs"]=FileInfo("ecs.tsv", subfolder=os.path.join("humann","merged"),
         description=("A tab-delimited file with samples as columns and ecs as rows. ",
             "This file is a merged set of ecs for all samples generated from the gene ",
-            "families computed by HUMAnN2. This file contains stratified counts as RPKs."))
-    file_info["pathabundance"]=FileInfo("pathabundance.tsv", subfolder=os.path.join("humann2","merged"),
+            "families computed by HUMAnN. This file contains stratified counts as RPKs."))
+    file_info["pathabundance"]=FileInfo("pathabundance.tsv", subfolder=os.path.join("humann","merged"),
         description=("A tab-delimited file with samples as columns and pathways ",
             "as rows. This file is a merged set of pathway abundances for all ",
-            "samples computed by HUMAnN2. This file contains stratified counts ",
+            "samples computed by HUMAnN. This file contains stratified counts ",
             "of non-normalized abundances."))
     
     # set the normed feature file names
-    file_info["genefamilies_relab"]=FileInfo("genefamilies_relab.tsv", subfolder=os.path.join("humann2","merged"))
-    file_info["ecs_relab"]=FileInfo("ecs_relab.tsv", subfolder=os.path.join("humann2","merged"))
-    file_info["pathabundance_relab"]=FileInfo("pathabundance_relab.tsv", subfolder=os.path.join("humann2","merged"),
+    file_info["genefamilies_relab"]=FileInfo("genefamilies_relab.tsv", subfolder=os.path.join("humann","merged"))
+    file_info["ecs_relab"]=FileInfo("ecs_relab.tsv", subfolder=os.path.join("humann","merged"),
+        description=("A tab-delimited file with samples as columns and ECs as rows.",
+                "This file is a merged set of EC abundances for all samples computed ",
+                "by HUMAnN. This file contains relative abundances."))
+    file_info["pathabundance_relab"]=FileInfo("pathabundance_relab.tsv", subfolder=os.path.join("humann","merged"),
         description=("A tab-delimited file with samples as columns and pathways ",
                 "as rows. This file is a merged set of pathway abundances for all ",
-                "samples computed by HUMAnN2. This file contains stratified counts ",
+                "samples computed by HUMAnN. This file contains stratified counts ",
                 "of relative abundances."))
     
     # set the feature count file names
-    file_info["genefamilies_relab_counts"]=FileInfo("humann2_genefamilies_relab_counts.tsv", subfolder=os.path.join("humann2","counts"))
-    file_info["ecs_relab_counts"]=FileInfo("humann2_ecs_relab_counts.tsv", subfolder=os.path.join("humann2","counts"))
-    file_info["pathabundance_relab_counts"]=FileInfo("humann2_pathabundance_relab_counts.tsv", subfolder=os.path.join("humann2","counts"))
+    file_info["genefamilies_relab_counts"]=FileInfo("humann_genefamilies_relab_counts.tsv", subfolder=os.path.join("humann","counts"))
+    file_info["ecs_relab_counts"]=FileInfo("humann_ecs_relab_counts.tsv", subfolder=os.path.join("humann","counts"))
+    file_info["pathabundance_relab_counts"]=FileInfo("humann_pathabundance_relab_counts.tsv", subfolder=os.path.join("humann","counts"))
     
     # set the all feature counts file names
-    file_info["feature_counts"]=FileInfo("humann2_feature_counts.tsv", subfolder=os.path.join("humann2","counts"),
+    file_info["feature_counts"]=FileInfo("humann_feature_counts.tsv", subfolder=os.path.join("humann","counts"),
         description=("A tab-delimited file with samples as rows and features ",
             "as columns. This file includes the total feature counts (non-stratified)",
-            "for the features computed by HUMAnN2 (genes, ecs, and pathways)."))
-    file_info["humann2_read_counts"]=FileInfo("humann2_read_and_species_count_table.tsv", subfolder=os.path.join("humann2","counts"),
+            "for the features computed by HUMAnN (genes, ecs, and pathways)."))
+    file_info["humann_read_counts"]=FileInfo("humann_read_and_species_count_table.tsv", subfolder=os.path.join("humann","counts"),
         description=("A tab-delimited file with samples as rows and counts as columns.",
-            "This file was created using the HUMAnN2 logs. It includes the total number ",
+            "This file was created using the HUMAnN logs. It includes the total number ",
             "of species used to generate the custom database, the total number of initial",
             "reads, and the total reads aligning for both search steps."))
     
     # set the names for the rna/dna normed files
-    file_info["genefamilies_norm_ratio"]=FileInfo("rna_dna_relative_expression_unstratified.tsv",subfolder=os.path.join("humann2","rna_dna_norm","genes"),
+    file_info["genefamilies_norm_ratio"]=FileInfo("rna_dna_relative_expression_unstratified.tsv",subfolder=os.path.join("humann","rna_dna_norm","genes"),
         description=("A tab-delimited file with samples as columns and genes as rows. ",
             "This file includes the normalized RNA abundances as a ratio to DNA abundance. ",
             "This file does not include stratified features."))
-    file_info["ecs_norm_ratio"]=FileInfo("rna_dna_relative_expression_unstratified.tsv",subfolder=os.path.join("humann2","rna_dna_norm","ecs"),
+    file_info["ecs_norm_ratio"]=FileInfo("rna_dna_relative_expression_unstratified.tsv",subfolder=os.path.join("humann","rna_dna_norm","ecs"),
         description=("A tab-delimited file with samples as columns and ecs as rows. ",
             "This file includes the normalized RNA abundances as a ratio to DNA abundance. ",
             "This file does not include stratified features."))
-    file_info["paths_norm_ratio"]=FileInfo("rna_dna_relative_expression_unstratified.tsv",subfolder=os.path.join("humann2","rna_dna_norm","paths"),
+    file_info["paths_norm_ratio"]=FileInfo("rna_dna_relative_expression_unstratified.tsv",subfolder=os.path.join("humann","rna_dna_norm","paths"),
         description=("A tab-delimited file with samples as columns and pathways as rows. ",
             "This file includes the normalized RNA abundances as a ratio to DNA abundance. ",
             "This file does not include stratified features."))
