@@ -125,7 +125,7 @@ def cutadapt_do(task):
     utilities.run_task(command, depends=task.depends, targets=task.targets)
 
 
-def filter_trim(workflow,input_folder,output_folder,maxee,trunc_len_max,pair_id,threads):
+def filter_trim(workflow,input_folder,output_folder,maxee,trunc_len_max,pair_id,threads,trunc_len_rev_offset):
     
          """ Filters samples by maxee and trims them, renders quality control plots
          of forward and reverse reads for each sample, creates read counts tsv and rds files.
@@ -163,12 +163,13 @@ def filter_trim(workflow,input_folder,output_folder,maxee,trunc_len_max,pair_id,
                --readcounts_tsv_path=[targets[0]]\
                --readcounts_rds_path=[targets[1]]\
                --reads_plotF=[targets[2]]\
-               --reads_plotR=[targets[3]]\
+               --reads_plotR=[args[7]]\
                --pair_id=[args[4]]\
-               --threads=[args[5]]",
+               --threads=[args[5]]\
+               --trunc_len_rev_offset='[args[6]]'",
              depends =[TrackedDirectory(input_folder)],
-             targets = [readcounts_tsv_path, readcounts_rds_path, reads_plotF_png, reads_plotR_png],
-             args = [input_folder, output_folder, maxee, trunc_len_max, pair_id, threads],
+             targets = [readcounts_tsv_path, readcounts_rds_path, reads_plotF_png],
+             args = [input_folder, output_folder, maxee, trunc_len_max, pair_id, threads, trunc_len_rev_offset, reads_plotR_png],
              vars = [script_path,filtered_dir],
              name ="filter_and_trim"
              )
@@ -207,13 +208,13 @@ def learn_error(workflow, output_folder, filtered_dir, readcounts_tsv_path, thre
                --output_dir=[args[0]]\
                --filtered_dir=[args[1]]\
                --error_ratesF_png=[targets[0]]\
-               --error_ratesR_png=[targets[1]]\
-               --error_ratesF_path=[targets[2]]\
-               --error_ratesR_path=[targets[3]]\
+               --error_ratesR_png=[args[2]]\
+               --error_ratesF_path=[targets[1]]\
+               --error_ratesR_path=[args[3]]\
                --threads=[vars[1]]",
              depends = [readcounts_tsv_path],
-             targets = [error_ratesF_png, error_ratesR_png, error_ratesF_path, error_ratesR_path],  
-             args = [output_folder, filtered_dir],
+             targets = [error_ratesF_png, error_ratesF_path],  
+             args = [output_folder, filtered_dir, error_ratesR_png, error_ratesR_path],
              vars = [script_path, threads],
              name = "learn_error_rates"
              )
@@ -248,21 +249,21 @@ def merge_paired_ends(workflow, output_dir, filtered_dir, error_ratesF_path, err
               --output_dir=[args[0]]\
               --filtered_dir=[args[1]]\
               --error_ratesF_path=[depends[0]]\
-              --error_ratesR_path=[depends[1]]\
+              --error_ratesR_path=[args[4]]\
               --mergers_file_path=[targets[0]]\
               --threads=[vars[1]]\
               --minoverlap=[args[2]]\
               --maxmismatch=[args[3]]",
-            depends = [error_ratesF_path, error_ratesR_path],
+            depends = [error_ratesF_path],
             targets = [mergers_file_path],                       
-            args = [output_dir, filtered_dir, minoverlap, maxmismatch],
+            args = [output_dir, filtered_dir, minoverlap, maxmismatch, error_ratesR_path],
             vars = [script_path, threads],
             name = "dereplicate_and_merge"
             )
         return mergers_file_path
     
 
-def const_seq_table(workflow, output_folder, filtered_dir,  mergers_file_path, threads):
+def const_seq_table(workflow, output_folder, filtered_dir,  mergers_file_path, threads, min_fold_parent_over_abundance):
     
          """ Builds ASV table, removes chimeras, creates read counts at each step, and fasta file with all sequences
             
@@ -304,17 +305,18 @@ def const_seq_table(workflow, output_folder, filtered_dir,  mergers_file_path, t
               --asv_tsv=[vars[3]]\
               --seqtab_file_path=[targets[1]]\
               --seqs_fasta_path=[targets[2]]\
-              --threads=[vars[1]]",
+              --threads=[vars[1]]\
+              --min_fold_parent_over_abundance=[vars[4]]",
             depends = [mergers_file_path,TrackedExecutable("R", version_command="echo '" +  version_script + "' `" + version_script + "`")],
             targets = [read_counts_steps_path, seqtab_file_path, seqs_fasta_path],
             args = [output_folder, filtered_dir],
-            vars = [script_path, threads, readcounts_rds, asv_tsv ],
+            vars = [script_path, threads, readcounts_rds, asv_tsv, min_fold_parent_over_abundance ],
             name = "construct_sequence_table"
             )
          return seqtab_file_path, read_counts_steps_path, seqs_fasta_path
 
 
-def assign_taxonomy(workflow, output_folder, seqtab_file_path, ref_path, threads):
+def assign_taxonomy(workflow, output_folder, seqtab_file_path, ref_path, threads, tryRC):
     
          """ Assigns taxonomy using green genes, silva, or rdp database, creates closed reference file
             
@@ -348,8 +350,8 @@ def assign_taxonomy(workflow, output_folder, seqtab_file_path, ref_path, threads
              refdb_path = config.SixteenS().greengenes_dada2
              refdb_species_path = "None"
 
-         script_path = utilities.get_package_file("assign_taxonomy", "Rscript")
-             
+         script_path = utilities.get_package_file("assign_taxonomy", "Rscript")             
+
          workflow.add_task(
             "[vars[2]] \
               --output_dir=[args[0]]\
@@ -357,11 +359,13 @@ def assign_taxonomy(workflow, output_folder, seqtab_file_path, ref_path, threads
               --refdb_species_path=[vars[1]]\
               --seqtab_file_path=[depends[0]]\
               --otu_closed_ref_path=[targets[0]]\
-              --threads=[vars[3]]",
+              --threads=[vars[3]]\
+              --tryRC=[vars[4]] &&\
+              check_for_reverse_reads.py --input [targets[0]]",
             depends = [seqtab_file_path],
             targets = [otu_closed_ref_path],                              
             args = [output_folder],
-            vars =[refdb_path, refdb_species_path, script_path, threads],
+            vars =[refdb_path, refdb_species_path, script_path, threads, tryRC],
             name = "assign_taxonomy"
             )         
      
