@@ -38,7 +38,7 @@ from biobakery_workflows import data
 BOWTIE2_EXTENSION=".1.bt2"
 
 def kneaddata(workflow, input_files, extension, output_folder, threads, paired=None, 
-    databases=None, pair_identifier=None, additional_options=None, remove_intermediate_output=None):
+    databases=None, pair_identifier=None, additional_options=None, remove_intermediate_output=None, scratch_dir=None):
     """Run kneaddata
     
     This set of tasks will run kneaddata on the input files provided. It will run with
@@ -58,9 +58,10 @@ def kneaddata(workflow, input_files, extension, output_folder, threads, paired=N
             the first pair in the set (optional).
         additional_options (string): Additional options when running kneaddata (optional).
         remove_intermediate_output (bool): Remove intermediate output files.
+        scratch_dir (string): Folder to write scratch files.
         
     Requires:
-        kneaddata v0.6.1+: A tool to perform quality control on metagenomic and
+        kneaddata v0.11.0: A tool to perform quality control on metagenomic and
             metatranscriptomic sequencing data
         
     Returns:
@@ -89,32 +90,31 @@ def kneaddata(workflow, input_files, extension, output_folder, threads, paired=N
         
     # get the kneaddata final output files
     main_folder=os.path.join("kneaddata","main")
-    kneaddata_output_repeats_removed_fastq = utilities.name_files(sample_names, output_folder, subfolder=main_folder, extension="repeats.removed.fastq", create_folder=True)
-    kneaddata_output_fastq = utilities.name_files(sample_names, output_folder, subfolder=main_folder, extension="fastq", create_folder=True)
+    kneaddata_output_fastq = utilities.name_files(sample_names, output_folder, subfolder=main_folder, extension="fastq.gz", create_folder=True)
     kneaddata_output_logs = utilities.name_files(sample_names, output_folder, subfolder=main_folder, extension="log")
-    kneaddata_output_files = zip(kneaddata_output_fastq, kneaddata_output_logs)
+    kneaddata_output_files = list(zip([filename.replace(".gz","") for filename in kneaddata_output_fastq], kneaddata_output_fastq, kneaddata_output_logs))
 
     # get the output folder
     kneaddata_output_folder = os.path.dirname(kneaddata_output_files[0][0])
-
-    rename_final_output = ""        
+ 
     if paired:
         # reorder the input files so they are a set of paired files
-        input_files=zip(input_files[0],input_files[1])
+        input_files=list(zip(input_files[0],input_files[1]))
         # add the second input file to the kneaddata arguments
         # also add the option to cat the final output files into a single file
-        second_input_option=" --input [depends[1]] --cat-final-output "
+        first_input_option=" --input1 [depends[0]] "
+        second_input_option=" --input2 [depends[1]] --cat-final-output "
         # determine time/memory equations based on the two input files
-        time_equation="3*6*60 if ( file_size('[depends[0]]') + file_size('[depends[1]]') ) < 10 else 5*6*60"
+        time_equation="5*6*60 if ( file_size('[depends[0]]') + file_size('[depends[1]]') ) < 10 else 7*6*60"
         mem_equation="3*12*1024 if ( file_size('[depends[0]]') + file_size('[depends[1]]') ) < 10 else 6*12*1024"
     else:
         # the second input option is not used since these are single-end input files
-        second_input_option=" "
+        # always cat the final output (which could be more then one file for the case of a bam input file with paired-end reads)
+        first_input_option=" --unpaired [depends[0]] "
+        second_input_option=" --cat-final-output "
         # determine time/memory equations based on the single input file
         time_equation="3*6*60 if file_size('[depends[0]]') < 10 else 5*6*60"
         mem_equation="3*12*1024 if file_size('[depends[0]]') < 10 else 6*12*1024"
-        # need to rename the final output file here to the sample name
-        rename_final_output = " && mv [args[3]] [targets[0]]"
         
     # set additional options to empty string if not provided
     if additional_options is None:
@@ -125,6 +125,10 @@ def kneaddata(workflow, input_files, extension, output_folder, threads, paired=N
     # also run tandem repeat filtering
     additional_options+=" --serial --run-trf "
 
+    # add scratch folder if provided
+    if scratch_dir:
+        additional_options+=" --scratch '{}' ".format(scratch_dir)
+
     # create the database command option string to provide zero or more databases to kneaddata
     if databases is None or databases=="":
         optional_arguments=""
@@ -144,13 +148,12 @@ def kneaddata(workflow, input_files, extension, output_folder, threads, paired=N
         additional_options+=" --remove-intermediate-output "
     
     # create a task for each set of input and output files to run kneaddata
-    # rename file with repeats in name to only sample name
-    for sample, depends, targets, intermediate_file in zip(sample_names, input_files, kneaddata_output_files, kneaddata_output_repeats_removed_fastq):
+    for sample, depends, targets in zip(sample_names, input_files, kneaddata_output_files):
         workflow.add_task_gridable(
-            "kneaddata --input [depends[0]] --output [args[0]] --threads [args[1]] --output-prefix [args[2]] "+second_input_option+optional_arguments+" "+additional_options+rename_final_output,
+            "kneaddata"+first_input_option+"--output [args[0]] --threads [args[1]] --output-prefix [args[2]] "+second_input_option+optional_arguments+" "+additional_options+" && gzip -f [args[3]] ",
             depends=utilities.add_to_list(depends,TrackedExecutable("kneaddata")),
-            targets=targets,
-            args=[kneaddata_output_folder, threads, sample, intermediate_file],
+            targets=targets[1:3],
+            args=[kneaddata_output_folder, threads, sample, targets[0]],
             time=time_equation, # 6 hours or more depending on file size
             mem=mem_equation, # 12 GB or more depending on file size
             cores=threads, # time/mem based on 8 cores
@@ -209,7 +212,7 @@ def kneaddata_read_count_table(workflow, input_files, output_folder):
 
 
 def quality_control(workflow, input_files, extension, output_folder, threads, databases=None, 
-    pair_identifier=None, additional_options=None, remove_intermediate_output=None):
+    pair_identifier=None, additional_options=None, remove_intermediate_output=None, scratch_dir=None):
     """Quality control tasks for whole genome shotgun sequences
     
     This set of tasks performs quality control on whole genome shotgun
@@ -227,6 +230,7 @@ def quality_control(workflow, input_files, extension, output_folder, threads, da
             the first pair in the set (optional).
         additional_options (string): Additional options when running kneaddata (optional).
         remove_intermediate_output (bool): Remove intermediate output files.
+        scratch_dir (string): Folder to write scratch files.
         
     Requires:
         kneaddata v0.6.1+: A tool to perform quality control on metagenomic and
@@ -267,7 +271,7 @@ def quality_control(workflow, input_files, extension, output_folder, threads, da
     # create a task for each set of input and output files to run kneaddata
     kneaddata_output_fastq, kneaddata_output_logs=kneaddata(workflow, input_files, extension,
         output_folder, threads, paired, databases, pair_identifier, additional_options,
-        remove_intermediate_output)
+        remove_intermediate_output, scratch_dir)
     
     # create the read count table
     kneaddata_read_count_file=kneaddata_read_count_table(workflow, kneaddata_output_logs, output_folder)
@@ -275,7 +279,7 @@ def quality_control(workflow, input_files, extension, output_folder, threads, da
     return kneaddata_output_fastq, kneaddata_read_count_file
 
 
-def taxonomic_profile(workflow,input_files,output_folder,threads,input_extension,already_profiled=False):
+def taxonomic_profile(workflow,input_files,output_folder,threads,input_extension,already_profiled=False,options=""):
     """Taxonomic profile for whole genome shotgun sequences
     
     This set of tasks performs taxonomic profiling on whole genome shotgun
@@ -286,18 +290,18 @@ def taxonomic_profile(workflow,input_files,output_folder,threads,input_extension
         workflow (anadama2.workflow): An instance of the workflow class.
         input_files (list): A list of paths to fastq files already run through quality control.
         output_folder (string): The path of the output folder.
-        threads (int): The number of threads/cores for metaphlan2 to use.
+        threads (int): The number of threads/cores for metaphlan to use.
         input_extension (string): The extension for the input files.
-        already_profiled (bool): Indicates if the input files need to be run through metaphlan2.
+        already_profiled (bool): Indicates if the input files need to be run through metaphlan.
             If not, just join profiles and count species.
         
     Requires:
-        metaphlan2 v2.5.0+: A tool to profile the composition of microbial communities.
-        humann2 v0.9.6+: A tool for functional profiling (only humann2_join_tables is required).
+        metaphlan v3.0.0+: A tool to profile the composition of microbial communities.
+        humann v0.9.6+: A tool for functional profiling (only humann_join_tables is required).
         
     Returns:
         string: A file of the merged taxonomic profiles from all samples.
-        list: A list of the sam files generated by metaphlan2.
+        list: A list of the sam files generated by metaphlan.
         
     Example:
         from anadama2 import Workflow
@@ -325,12 +329,12 @@ def taxonomic_profile(workflow,input_files,output_folder,threads,input_extension
     # get the sample names from the input files
     sample_names=utilities.sample_names(input_files,input_extension)
     
-    # get a list of metaphlan2 output files, one for each input file
-    metaphlan2_profile_tag="taxonomic_profile"
-    main_folder=os.path.join("metaphlan2","main")
-    metaphlan2_output_files_profile = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag=metaphlan2_profile_tag, extension="tsv", create_folder=True)
-    metaphlan2_output_files_sam = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag="bowtie2", extension="sam")
-    metaphlan2_output_folder = os.path.dirname(metaphlan2_output_files_profile[0])
+    # get a list of metaphlan output files, one for each input file
+    metaphlan_profile_tag="taxonomic_profile"
+    main_folder=os.path.join("metaphlan","main")
+    metaphlan_output_files_profile = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag=metaphlan_profile_tag, extension="tsv", create_folder=True)
+    metaphlan_output_files_sam = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag="bowtie2", extension="sam")
+    metaphlan_output_folder = os.path.dirname(metaphlan_output_files_profile[0])
     
     # determine the input file type based on the extension
     if input_extension in ["fasta","fasta.gz","fa","fa.gz"]:
@@ -338,45 +342,45 @@ def taxonomic_profile(workflow,input_files,output_folder,threads,input_extension
     else:
         input_type="fastq"
     
-    # run metaphlan2 on each of the kneaddata output files
+    # run metaphlan on each of the kneaddata output files
     if not already_profiled:
-        for sample, depend_fastq, target_profile, target_sam in zip(sample_names, input_files, metaphlan2_output_files_profile, metaphlan2_output_files_sam):
+        for sample, depend_fastq, target_profile, target_sam in zip(sample_names, input_files, metaphlan_output_files_profile, metaphlan_output_files_sam):
             workflow.add_task_gridable(
-                "metaphlan2.py [depends[0]] --input_type [args[2]] --output_file [targets[0]] --samout [targets[1]] --nproc [args[0]] --no_map --tmp_dir [args[1]]",
-                depends=[depend_fastq,TrackedExecutable("metaphlan2.py")],
+                "metaphlan [depends[0]] --input_type [args[2]] --output_file [targets[0]] --samout [targets[1]] --nproc [args[0]] --no_map --tmp_dir [args[1]] "+options,
+                depends=[depend_fastq,TrackedExecutable("metaphlan")],
                 targets=[target_profile,target_sam],
-                args=[threads,metaphlan2_output_folder,input_type],
+                args=[threads,metaphlan_output_folder,input_type],
                 time="2*4*60 if file_size('[depends[0]]') < 25 else 5*3*60", # 3 hours or more depending on input file size
-                mem="12*1024 if file_size('[depends[0]]') < 25 else 4*12*1024", # 12 GB or more depending on input file size
+                mem="2*12*1024 if file_size('[depends[0]]') < 25 else 5*12*1024", # 12 GB or more depending on input file size
                 cores=threads, # time/mem based on 8 cores
-                name=utilities.name_task(sample,"metaphlan2"))
+                name=utilities.name_task(sample,"metaphlan"))
     else:
         # set the names of the already profiled outputs
-        metaphlan2_output_files_profile = input_files
-        metaphlan2_output_folder = os.path.dirname(input_files[0])
+        metaphlan_output_files_profile = input_files
+        metaphlan_output_folder = os.path.dirname(input_files[0])
     
     # merge all of the metaphlan taxonomy tables
-    metaphlan2_merged_output = files.ShotGun.path("taxonomic_profile", output_folder)
+    metaphlan_merged_output = files.ShotGun.path("taxonomic_profile", output_folder)
     
-    # run the humann2 join script to merge all of the metaphlan2 profiles
+    # run the join taxonomic profiles script to merge all of the metaphlan profiles
     workflow.add_task(
-        "humann2_join_tables --input [args[0]] --output [targets[0]] --file_name [args[1]]",
-        depends=metaphlan2_output_files_profile,
-        targets=metaphlan2_merged_output,
-        args=[metaphlan2_output_folder, metaphlan2_profile_tag],
-        name="metaphlan2_join_taxonomic_profiles")
+        "join_taxonomic_profiles.py --input [args[0]] --output [targets[0]] --file_name [args[1]]",
+        depends=metaphlan_output_files_profile,
+        targets=metaphlan_merged_output,
+        args=[metaphlan_output_folder, metaphlan_profile_tag],
+        name="metaphlan_join_taxonomic_profiles")
    
     # get the name for the file to write the species counts
-    metaphlan2_species_counts_file = files.ShotGun.path("species_counts",output_folder,create_folder=True)
+    metaphlan_species_counts_file = files.ShotGun.path("species_counts",output_folder,create_folder=True)
 
     # create a file of species counts
     workflow.add_task(
     "count_features.py --input [depends[0]] --output [targets[0]] --include s__ --filter t__ --reduce-sample-name",
-    depends=metaphlan2_merged_output,
-    targets=metaphlan2_species_counts_file,
-    name="metaphlan2_count_species") 
+    depends=metaphlan_merged_output,
+    targets=metaphlan_species_counts_file,
+    name="metaphlan_count_species") 
 
-    return metaphlan2_merged_output, metaphlan2_output_files_profile, metaphlan2_output_files_sam
+    return metaphlan_merged_output, metaphlan_output_files_profile, metaphlan_output_files_sam
 
 def merge_pairs(workflow,input_files,extension,pair_identifier,output_folder):
     """ Merge the paired files into a single file 
@@ -414,9 +418,12 @@ def merge_pairs(workflow,input_files,extension,pair_identifier,output_folder):
         
         # add a task to merge each pair set
         for pair1, pair2, target in zip(input_pair1, input_pair2, merged_files):
-            workflow.add_task(
+            workflow.add_task_gridable(
                 command+" [depends[0]] [depends[1]] > [targets[0]]",
                 depends=[pair1,pair2],
+                time=10,
+                mem=1*1024,
+                cores=1,
                 targets=target)
     else:
         merged_files=input_files
@@ -443,7 +450,7 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
         remove_intermediate_output (bool): Remove intermediate output files.
         
     Requires:
-        humann2 v0.9.6+: A tool for functional profiling.
+        humann v0.9.6+: A tool for functional profiling.
         
     Returns:
         string: A file of the merged gene families (relative abundance) for all samples.
@@ -472,25 +479,25 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
     # get the sample names from the input files
     sample_names=utilities.sample_names(input_files,extension)
     
-    ### Step 1: Run humann2 on all input files ###
+    ### Step 1: Run humann on all input files ###
 
-    # get a list of output files, one for each input file, with the humann2 output file names
-    main_folder=os.path.join("humann2","main")
+    # get a list of output files, one for each input file, with the humann output file names
+    main_folder=os.path.join("humann","main")
     genefamiles = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag="genefamilies", extension="tsv", create_folder=True)
     pathabundance = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag="pathabundance", extension="tsv")
     pathcoverage = utilities.name_files(sample_names, output_folder, subfolder=main_folder, tag="pathcoverage", extension="tsv")
 
     # get the list of the log files that will be created, one for each input file, set to the same folder as the main output files
     log_files = utilities.name_files(sample_names, output_folder, subfolder=main_folder, extension="log")
-    # get the name for the file of read and species counts created from the humann2 log outputs
-    log_counts = files.ShotGun.path("humann2_read_counts",output_folder,create_folder=True)
+    # get the name for the file of read and species counts created from the humann log outputs
+    log_counts = files.ShotGun.path("humann_read_counts",output_folder,create_folder=True)
 
-    humann2_output_folder = os.path.dirname(genefamiles[0])
+    humann_output_folder = os.path.dirname(genefamiles[0])
     
     # if taxonomic profiles are provided, add these to the targets and the command option
     if taxonomic_profiles:
         optional_profile_args=" --taxonomic-profile [depends[1]] "
-        depends=zip(input_files,taxonomic_profiles)
+        depends=list(zip(input_files,taxonomic_profiles))
     else:
         optional_profile_args=""
         depends=input_files
@@ -502,42 +509,42 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
     if not options is None:
         optional_profile_args+=" "+options+" "
  
-    # create a task to run humann2 on each of the kneaddata output files
+    # create a task to run humann on each of the kneaddata output files
     for sample, depend_fastq, target_gene, target_path, target_coverage, target_log in zip(sample_names, depends, genefamiles, pathabundance, pathcoverage, log_files):
         workflow.add_task_gridable(
-            "humann2 --input [depends[0]] --output [args[0]] --o-log [targets[3]] --threads [args[1]]"+optional_profile_args,
-            depends=utilities.add_to_list(depend_fastq,TrackedExecutable("humann2")),
+            "humann --input [depends[0]] --output [args[0]] --o-log [targets[3]] --threads [args[1]]"+optional_profile_args,
+            depends=utilities.add_to_list(depend_fastq,TrackedExecutable("humann")),
             targets=[target_gene, target_path, target_coverage, target_log],
-            args=[humann2_output_folder, threads],
-            time="24*60 if file_size('[depends[0]]') < 25 else 6*24*60", # 24 hours or more depending on file size
-            mem="32*1024 if file_size('[depends[0]]') < 25 else 3*32*1024", # 32 GB or more depending on file size
+            args=[humann_output_folder, threads],
+            time="3*24*60 if file_size('[depends[0]]') < 25 else 8*24*60", # 24 hours or more depending on file size
+            mem="3*36*1024 if file_size('[depends[0]]') < 25 else 3*48*1024", # 32 GB or more depending on file size
             cores=threads,
-            name=utilities.name_task(sample,"humann2"))
+            name=utilities.name_task(sample,"humann"))
 
-    # create a task to get the read and species counts for each humann2 run from the log files
+    # create a task to get the read and species counts for each humann run from the log files
     workflow.add_task(
-        "get_counts_from_humann2_logs.py --input [args[0]] --output [targets[0]]",
+        "get_counts_from_humann_logs.py --input [args[0]] --output [targets[0]]",
         depends=log_files,
         targets=log_counts,
-        args=humann2_output_folder,
-        name="humann2_count_alignments_species")
+        args=humann_output_folder,
+        name="humann_count_alignments_species")
     
     ### STEP #2: Regroup UniRef90 gene families to ecs ###
     
     # get a list of all output ec files
     ec_files = utilities.name_files(sample_names, output_folder, 
-        subfolder=os.path.join("humann2","regrouped"), tag="ecs", 
+        subfolder=os.path.join("humann","regrouped"), tag="ecs", 
         extension="tsv", create_folder=True)
     
     # get ec files for all of the gene families files
     workflow.add_task_group_gridable(
-        "humann2_regroup_table --input [depends[0]] --output [targets[0]] --groups uniref90_level4ec",
+        "humann_regroup_table --input [depends[0]] --output [targets[0]] --groups uniref90_level4ec",
         depends=genefamiles,
         targets=ec_files,
         time=10, # 10 minutes
         mem=5*1024, # 5 GB
         cores=1,
-        name=map(lambda sample: utilities.name_task(sample,"humann2_regroup_UniRef2EC"), sample_names))
+        name=map(lambda sample: utilities.name_task(sample,"humann_regroup_UniRef2EC"), sample_names))
 
     
     ### STEP #3: Merge gene families, ecs, and pathway abundance files
@@ -553,16 +560,16 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
     file_basenames=["genefamilies","ecs","pathabundance"]
     for depends, targets, basename in zip(all_depends, all_targets, file_basenames):
         workflow.add_task(
-            "humann2_join_tables --input [args[0]] --output [targets[0]] --file_name [args[1]]",
+            "humann_join_tables --input [args[0]] --output [targets[0]] --file_name [args[1]]",
             depends=depends,
             targets=targets,
             args=[os.path.dirname(depends[0]),basename],
-            name="humann2_join_tables_"+basename)
+            name="humann_join_tables_"+basename)
     
     ### STEP #4: Normalize gene families, ecs, and pathway abundance to relative abundance (then merge files) ###
     
     # get a list of files for normalized ec, gene families, and pathway abundance
-    relab_folder=os.path.join("humann2","relab")
+    relab_folder=os.path.join("humann","relab")
     norm_genefamily_files = utilities.name_files(genefamiles, output_folder, subfolder=os.path.join(relab_folder,"genes"), tag="relab", create_folder=True)
     norm_ec_files = utilities.name_files(ec_files, output_folder,  subfolder=os.path.join(relab_folder,"ecs"), tag="relab", create_folder=True)
     norm_pathabundance_files = utilities.name_files(pathabundance, output_folder,  subfolder=os.path.join(relab_folder,"pathways"), tag="relab", create_folder=True)
@@ -570,9 +577,9 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
     # normalize the genefamily, ec, and pathabundance files
     # do not include special features (ie UNMAPPED, UNINTEGRATED, UNGROUPED) in norm computation
     renorm_task_names=len(norm_genefamily_files)*["genes"] + len(norm_ec_files)*["ecs"] + len(norm_pathabundance_files)*["pathways"]
-    renorm_task_names=[utilities.name_task(sample,"humann2_renorm_"+type+"_relab") for sample, type in zip(itertools.cycle(sample_names),renorm_task_names)]
+    renorm_task_names=[utilities.name_task(sample,"humann_renorm_"+type+"_relab") for sample, type in zip(itertools.cycle(sample_names),renorm_task_names)]
     workflow.add_task_group_gridable(
-        "humann2_renorm_table --input [depends[0]] --output [targets[0]] --units relab --special n",
+        "humann_renorm_table --input [depends[0]] --output [targets[0]] --units relab --special n",
         depends=genefamiles + ec_files + pathabundance,
         targets=norm_genefamily_files + norm_ec_files + norm_pathabundance_files,
         time=15, # 15 minutes
@@ -592,11 +599,11 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
     all_types=["genes_relab","ecs_relab","pathways_relab"]
     for depends, targets, input_type in zip(all_depends, all_targets, all_types):
         workflow.add_task(
-            "humann2_join_tables --input [args[0]] --output [targets[0]]",
+            "humann_join_tables --input [args[0]] --output [targets[0]]",
             depends=depends,
             targets=targets,
             args=[os.path.dirname(depends[0])],
-            name="humann2_join_tables_"+input_type)
+            name="humann_join_tables_"+input_type)
 
     # get feature counts for the ec, gene families, and pathways
     genefamilies_counts = files.ShotGun.path("genefamilies_relab_counts", output_folder)
@@ -606,16 +613,16 @@ def functional_profile(workflow,input_files,extension,output_folder,threads,taxo
         "count_features.py --input [depends[0]] --output [targets[0]] --reduce-sample-name --ignore-un-features --ignore-stratification",
         depends=[merged_genefamilies_relab, merged_ecs_relab, merged_pathabundance_relab],
         targets=[genefamilies_counts, ecs_counts, pathabundance_counts],
-        name=["humann2_count_features_genes","humann2_count_features_ecs","humann2_count_features_pathways"])
+        name=["humann_count_features_genes","humann_count_features_ecs","humann_count_features_pathways"])
     
     # merge the feature counts into a single file
     all_feature_counts = files.ShotGun.path("feature_counts", output_folder)
     workflow.add_task(
-        "humann2_join_tables --input [args[0]] --output [targets[0]] --file_name _relab_counts.tsv",
+        "humann_join_tables --input [args[0]] --output [targets[0]] --file_name _relab_counts.tsv",
         depends=[genefamilies_counts, ecs_counts, pathabundance_counts],
         targets=all_feature_counts,
         args=[os.path.dirname(genefamilies_counts)],
-        name="humann2_merge_feature_counts")
+        name="humann_merge_feature_counts")
 
         
     return merged_genefamilies_relab, merged_ecs_relab, merged_pathabundance_relab, merged_genefamilies, merged_ecs, merged_pathabundance
@@ -624,7 +631,7 @@ def norm_ratio(workflow, wms_genes, wms_ecs, wms_paths, wts_genes, wts_ecs, wts_
     """Compute a rna/dna normalized ratio
     
     Compute the ratio for the genes, ecs, and pathway abundances using the original
-    output files generated by HUMAnN2 (merged for all samples). These files have not
+    output files generated by HUMAnN (merged for all samples). These files have not
     had any normalization applied.
     
     Args:
@@ -696,37 +703,37 @@ def strainphlan(task,threads,clade_number,clade_list,reference_folder,marker_fol
             profile_clade=None
             
     if profile_clade:
-        command = "strainphlan.py --ifn_samples [args[0]]/*.markers --output_dir [args[1]] "+\
-            "--clades [args[2]] --nprocs_main [args[3]] --keep_alignment_files "+options
+        command = "strainphlan --samples [args[0]]/*/*.pkl --output_dir [args[1]] "+\
+            "--clade [args[2]] --nprocs [args[3]] "+options
             
         # add the marker files to the command
         all_marker_file=os.path.join(marker_folder,"all_markers.fasta")
-        marker_file=os.path.join(marker_folder,profile_clade+".markers.fasta")
+        marker_file=os.path.join(marker_folder,profile_clade+".fna")
         
         # generate the marker file if it does not already exist
         if not os.path.isfile(marker_file):
             # get the pkl file relative to the strainphlan install
             try:
-                strainphlan_pkl=os.path.join(os.path.dirname(subprocess.check_output(["which","strainphlan.py"])),"metaphlan_databases","mpa_v20_m200.pkl")
+                import metaphlan
+                strainphlan_pkl=os.path.join(os.path.dirname(metaphlan.__file__),"metaphlan_databases","mpa_v30_CHOCOPhlAn_201901.pkl")
             except subprocess.CalledProcessError:
                 raise EnvironmentError("Unable to find strainphlan install.")
             
-            marker_command="extract_markers.py --mpa_pkl [depends[0]] "+\
-                "--ifn_markers [depends[1]] --clade [args[0]] "+\
-                "--ofn_markers [targets[0]]"
+            marker_command="extract_markers.py --database [depends[0]] "+\
+                "--clade [args[0]] --output_dir [args[1]]"
                 
             # create the marker file in the output folder
-            marker_file=os.path.join(os.path.dirname(task.targets[0].name),profile_clade+".markers.fasta")
+            marker_file=os.path.join(os.path.dirname(task.targets[0].name),profile_clade+".fna")
                 
-            return_code = utilities.run_task(marker_command,depends=[strainphlan_pkl,all_marker_file], 
-                targets=[marker_file],args=[profile_clade])
+            return_code = utilities.run_task(marker_command,depends=[strainphlan_pkl], 
+                targets=[marker_file],args=[profile_clade,os.path.dirname(marker_file)])
         
         # check that the marker file exists
         if not os.path.isfile(marker_file):
             raise EnvironmentError("Unable to find StrainPhlAn markers for clade "+ profile_clade)
 
         # add the marker file location (default or per workflow) to the command
-        command += " --ifn_markers "+marker_file       
+        command += " --clade_markers "+marker_file       
  
         # get the list of reference genomes
         genomes=set()
@@ -745,7 +752,7 @@ def strainphlan(task,threads,clade_number,clade_list,reference_folder,marker_fol
         
         # add the reference genome files to the command, if any are found
         if len(genomes):
-            command += " --ifn_ref_genomes " + " --ifn_ref_genomes ".join(genomes)
+            command += " --references " + " --references ".join(genomes)
         
         # write the output to the log
         command += " > [targets[0]] && touch [targets[1]] && if [ -f [args[1]]/RAxML_bestTree.[args[2]].tree ]; then cp [args[1]]/RAxML_bestTree.[args[2]].tree [targets[1]]; fi"
@@ -756,10 +763,10 @@ def strainphlan(task,threads,clade_number,clade_list,reference_folder,marker_fol
         
     # run the task
     return_code = utilities.run_task(command, depends=task.depends, targets=task.targets, 
-        args=[os.path.dirname(task.depends[0].name),os.path.dirname(task.targets[0].name),profile_clade,threads])
+        args=[os.path.abspath(os.path.join(os.path.dirname(task.depends[0].name),"..")),os.path.dirname(task.targets[0].name),profile_clade,threads])
     
 
-def strain_profile(workflow,sam_files,output_folder,threads,reference_folder,marker_folder,abundance_file,options="",max_species=20,strain_list="",min_depth=10):
+def strain_profile(workflow,sam_files,output_folder,threads,reference_folder,marker_folder,abundance_file,options="",max_species=20,strain_list=""):
     """Strain profile for whole genome shotgun sequences
     
     This set of tasks performs strain profiling on whole genome shotgun
@@ -768,7 +775,7 @@ def strain_profile(workflow,sam_files,output_folder,threads,reference_folder,mar
     
     Args:
         workflow (anadama2.workflow): An instance of the workflow class.
-        sam_files (list): A list of paths to sam files generated by MetaPhlAn2.
+        sam_files (list): A list of paths to sam files generated by MetaPhlAn.
         output_folder (string): The path of the output folder.
         threads (int): The number of threads/cores to use.
         reference_folder (string): The folder containing the reference files.
@@ -788,18 +795,23 @@ def strain_profile(workflow,sam_files,output_folder,threads,reference_folder,mar
 
     ### STEP #1: Identify markers for each of the samples
     # name the marker files based on the sam files
-    strainphlan_markers = utilities.name_files(sam_files, output_folder, subfolder="strainphlan", extension="markers", create_folder=True)
-     
+    strainphlan_markers_temp = utilities.name_files(sam_files, output_folder, subfolder="strainphlan", extension="pkl", create_folder=True)
+    # place each in its own output folder to allow for unique temp output folders for each run
+    strainphlan_markers=[]
+    for filename in strainphlan_markers_temp:
+        sample_name = os.path.basename(filename).split(".")[0]
+        strainphlan_markers.append(os.path.join(os.path.dirname(filename), sample_name, os.path.basename(filename)))
+
     # create a marker file from each sam file, require min depth
     for sam, markers in zip(sam_files, strainphlan_markers):
         sample_name=os.path.basename(sam).replace("_bowtie2.sam","")
         workflow.add_task_gridable(
-            "sample2markers.py --ifn_samples [depends[0]] --input_type sam --output_dir [args[0]] --nprocs [args[1]] --min_read_depth [args[2]]",
+            "remove_if_exists.py [args[0]] --is-folder && mkdir -p [args[0]] && sample2markers.py --input [depends[0]] --input_format sam --output_dir [args[0]] --nprocs [args[1]]",
             depends=sam,
             targets=markers,
-            args=[os.path.dirname(markers),threads,min_depth],
-            time=3*60, # 3 hours
-            mem=5*1024, # 5 GB
+            args=[os.path.dirname(markers),threads],
+            time=6*60, # 6 hours
+            mem=32*1024, # 32 GB
             cores=threads,
             name=utilities.name_task(sample_name,"strainphlan_sample2markers"))
 
@@ -807,10 +819,10 @@ def strain_profile(workflow,sam_files,output_folder,threads,reference_folder,mar
     clade_list = utilities.name_files("clades_list.txt", output_folder, subfolder="strainphlan")
     
     workflow.add_task(
-        "strainphlan.py --ifn_samples [args[0]]/*.markers --output_dir [args[0]] --print_clades_only > [targets[0]]",
+        "strainphlan --samples [args[0]]/*/*.pkl --output_dir [args[0]] --print_clades_only > [targets[0]] "+options,
         depends=strainphlan_markers,
         targets=clade_list,
-        args=os.path.dirname(strainphlan_markers[0]),
+        args=os.path.abspath(os.path.join(os.path.dirname(strainphlan_markers[0]),"..")),
         name="strainphlan_print_clades")
     
     # order the clades list by average abundance if list not provided
@@ -855,7 +867,7 @@ def get_panphlan_species_name(abundance_file, species_number, panphlan_db):
         # get the version number based on the files found
         possible_dbs=[]
         for file in os.listdir(panphlan_db):
-            if file.startswith("panphlan_"+selected_species) and file.endswith(BOWTIE2_EXTENSION):
+            if file.startswith(selected_species[0].upper()) and selected_species[1:] in file and file.endswith(BOWTIE2_EXTENSION):
                 possible_dbs.append(file)
 
         if not possible_dbs:
@@ -873,13 +885,13 @@ def panphlan_map(task,species_number,threads,panphlan_db,output_file):
 
     if selected_species:
         # get a single folder for this species database
-        species_db = os.path.join(panphlan_db, "panphlan_"+selected_species+BOWTIE2_EXTENSION)
+        species_db = os.path.join(panphlan_db, selected_species+BOWTIE2_EXTENSION)
     
         # run the task
         return_code = utilities.run_task(
-            "panphlan_map.py -c [args[0]] -i [depends[1]] -o [args[1]] --i_bowtie2_indexes [args[2]] --tmp [args[3]] --nproc [args[4]] --verbose > [targets[0]]", 
+            "panphlan_map.py -p [args[0]] -i [depends[1]] -o [args[1]] --indexes [args[2]] --nproc [args[3]] --verbose > [targets[0]]", 
             depends=task.depends+[species_db], targets=task.targets, 
-            args=[selected_species,output_file,panphlan_db,os.path.dirname(task.targets[0].name),threads])
+            args=[os.path.join(panphlan_db,selected_species+"_pangenome.tsv"),output_file,os.path.join(panphlan_db,selected_species),threads])
     else:
         # there is not a clade of this number, create an empty output file
         utilities.run_task("touch [targets[0]]", targets=task.targets)
@@ -893,16 +905,16 @@ def panphlan_profile(task,species_number,panphlan_db):
 
     if selected_species:
         # get a single folder for this species database
-        species_db = os.path.join(panphlan_db, "panphlan_"+selected_species+BOWTIE2_EXTENSION)
+        species_db = os.path.join(panphlan_db, selected_species+BOWTIE2_EXTENSION)
 
         # get the name of the species gene file target
         output_folder = os.path.dirname(task.depends[1].name)
         gene_target=os.path.join(output_folder,selected_species+"_gene_presence_absence.tsv")
         # run the task
         return_code = utilities.run_task(
-            "panphlan_profile.py -c [args[0]] -i [args[1]] --o_dna [targets[0]] --add_strains --i_bowtie2_indexes [args[2]] --verbose > [targets[1]]",
+            "panphlan_profiling.py -p [args[0]] -i [args[1]] --o_matrix [targets[0]] --verbose > [targets[1]]",
             depends=task.depends+[species_db], targets=[gene_target]+task.targets,
-            args=[selected_species,output_folder,panphlan_db])
+            args=[os.path.join(panphlan_db,selected_species+"_pangenome.tsv"),output_folder,panphlan_db])
     else:
         # there is not a clade of this number, create an empty output file
         utilities.run_task("touch [targets[0]]", targets=task.targets)
