@@ -31,7 +31,7 @@ from biobakery_workflows import utilities
 from biobakery_workflows import files
 
     
-def quality_control(workflow, method, fastq_file, output_folder, threads, maxee, trunc_len):
+def quality_control(workflow, method, fastq_file, output_folder, threads, maxee, trunc_len, fastq_ascii):
     """ Create a quality report, filter fastq, and then truncate fasta files
     
     Args:
@@ -51,17 +51,22 @@ def quality_control(workflow, method, fastq_file, output_folder, threads, maxee,
     """
     
     # generate a quality report that can be used again for filtering
-    qc_report = quality_report(workflow, method, fastq_file, output_folder, threads)
+    # increase qmax for old illumina format
+    qmax=45
+    if fastq_ascii != "33":
+        qmax=75
+
+    qc_report = quality_report(workflow, method, fastq_file, output_folder, threads, qmax)
         
     # filter the fastq file with the maxee scores
-    filtered_truncated_fasta, fasta = filter_fastq(workflow, method, fastq_file, output_folder, threads, maxee, trunc_len)
+    filtered_truncated_fasta, fasta = filter_fastq(workflow, method, fastq_file, output_folder, threads, maxee, trunc_len, fastq_ascii)
     
     # truncate reads based on length
-    truncated_fastas = truncate(workflow, method, [fasta], output_folder, threads, trunc_len)
+    truncated_fastas = truncate(workflow, method, [fasta], output_folder, threads, trunc_len, fastq_ascii)
     
     return filtered_truncated_fasta, truncated_fastas[0], fasta
 
-def merge_samples_and_rename(workflow, method, input_files, extension, output_folder, pair_identifier, threads):
+def merge_samples_and_rename(workflow, method, input_files, extension, output_folder, pair_identifier, threads, fastq_ascii):
     """ Merge the files, first if pairs, then rename sequence ids to match sample id
          Then merge all files into a single fastq file
 
@@ -83,7 +88,7 @@ def merge_samples_and_rename(workflow, method, input_files, extension, output_fo
     """
     
     # merge the files, if pairs, and then rename sequence ids to match sample ids
-    renamed_files = merge_pairs_and_rename(workflow, method, input_files, extension, output_folder, pair_identifier, threads)
+    renamed_files = merge_pairs_and_rename(workflow, method, input_files, extension, output_folder, pair_identifier, threads, fastq_ascii)
     
     # merge the renamed files into a single fastq file
     all_samples_fastq = merge_fastq(workflow, renamed_files, output_folder)
@@ -91,7 +96,7 @@ def merge_samples_and_rename(workflow, method, input_files, extension, output_fo
     return all_samples_fastq
 
 
-def merge_pairs(task, method, threads=1):
+def merge_pairs(task, method, threads=1, fastq_ascii="33"):
     """ Merge the pair files, allowing for empty input files 
     
         Args:
@@ -112,17 +117,17 @@ def merge_pairs(task, method, threads=1):
         # using usearch
         else:
             command="export OMP_NUM_THREADS=[args[0]]; " +\
-            "usearch -fastq_mergepairs [depends[0]] -reverse [depends[1]]  -fastqout [targets[0]] -fastqout_notmerged_fwd [targets[1]] -threads [args[0]]"
+            "usearch -fastq_mergepairs [depends[0]] -reverse [depends[1]]  -fastqout [targets[0]] -fastqout_notmerged_fwd [targets[1]] -threads [args[0]] -fastq_ascii [args[1]]"
         
     else:
         # the input files are empty, create empty output files
         command="touch [targets[0]] [targets[1]]"
         
     # run the task
-    return_code = utilities.run_task(command, depends=task.depends, targets=task.targets, args=threads)
+    return_code = utilities.run_task(command, depends=task.depends, targets=task.targets, args=[threads, fastq_ascii])
     
 
-def merge_pairs_and_rename(workflow, method, input_files, extension, output_folder, pair_identifier, threads):
+def merge_pairs_and_rename(workflow, method, input_files, extension, output_folder, pair_identifier, threads, fastq_ascii):
     """ Merge the files if pairs and rename sequence ids to match sample id
     
     Args:
@@ -183,7 +188,7 @@ def merge_pairs_and_rename(workflow, method, input_files, extension, output_fold
                     name="vsearch_fastq_mergepairs")
             else:
                 workflow.add_task(
-                    utilities.partial_function(merge_pairs,method="userach", threads=threads),
+                    utilities.partial_function(merge_pairs,method="userach", threads=threads, fastq_ascii=fastq_ascii),
                     depends=[read1, read2, TrackedExecutable("usearch")],
                     targets=[stitched_output, unjoined_output],
                     name="usearch_fastq_mergepairs")
@@ -275,7 +280,7 @@ def quality_report(workflow, method, fastq_file, output_folder, threads, qmax=45
     return qc_file
   
   
-def filter_fastq(workflow, method, fastq_file, output_folder, threads, maxee, trunc_len, qmax=45):
+def filter_fastq(workflow, method, fastq_file, output_folder, threads, maxee, trunc_len, fastq_ascii, qmax=45):
     """ Filter the fastq files using the maxee value
     
     Args:
@@ -310,10 +315,10 @@ def filter_fastq(workflow, method, fastq_file, output_folder, threads, maxee, tr
     else:
         workflow.add_task(
             "export OMP_NUM_THREADS=[args[0]]; "+\
-            "usearch -fastq_filter [depends[0]] -fastq_maxee [args[1]] -fastaout [targets[0]] -threads [args[0]] -fastaout_discarded [targets[1]] -fastq_trunclen [args[2]] -fastq_qmax [args[3]]",
+            "usearch -fastq_filter [depends[0]] -fastq_maxee [args[1]] -fastaout [targets[0]] -threads [args[0]] -fastaout_discarded [targets[1]] -fastq_trunclen [args[2]] -fastq_qmax [args[3]] -fastq_ascii [args[4]]",
             depends=[fastq_file,TrackedExecutable("usearch")],
             targets=[fasta_filtered_file, fasta_discarded_file],
-            args=[threads, maxee, trunc_len, qmax],
+            args=[threads, maxee, trunc_len, qmax, fastq_ascii],
             name="usearch_fastq_filter")
     
     # create a fasta file of all reads (included the discarded
@@ -326,7 +331,7 @@ def filter_fastq(workflow, method, fastq_file, output_folder, threads, maxee, tr
     return fasta_filtered_file, fasta_file
 
 
-def truncate(workflow, method, input_files, output_folder, threads, trunc_len):
+def truncate(workflow, method, input_files, output_folder, threads, trunc_len, fastq_ascii):
     """ Truncate the fasta sequences by length
     
     Args:
@@ -356,10 +361,10 @@ def truncate(workflow, method, input_files, output_folder, threads, trunc_len):
             name="vsearch_fastx_truncate")
     else:
         workflow.add_task_group(
-            "usearch -fastx_truncate [depends[0]] -trunclen [args[0]] -fastaout [targets[0]]",
+            "usearch -fastx_truncate [depends[0]] -trunclen [args[0]] -fastaout [targets[0]] -fastq_ascii [args[1]]",
             depends=input_files,
             targets=output_files,
-            args=trunc_len,
+            args=[trunc_len, fastq_ascii],
             name="usearch_fastx_truncate")
 
     return output_files
@@ -710,7 +715,7 @@ def build_otu_tables(workflow, reference_taxonomy, reference_fasta, reference_ma
     
     return closed_ref_tsv, closed_ref_fasta
 
-def run_picrust2(task, threads, otus=False):
+def run_picrust2(task, threads, otus=False, method="16s"):
     """ Run picrust2, first changing sequence ids to avoid all numeric (as per picrust2 tutorial) """
 
     picrust2_input_dir = os.path.dirname(task.depends[0].name)
@@ -731,6 +736,7 @@ def run_picrust2(task, threads, otus=False):
     with open(task.depends[1].name) as file_handle:
         with open(reformat_input_tsv, "w") as file_handle_write:
             header = file_handle.readline()
+            header="\t".join(header.split("\t")[:-1])+"\n"
             file_handle_write.write(header)
             for line in file_handle:
                 if otus:
@@ -738,13 +744,25 @@ def run_picrust2(task, threads, otus=False):
                 line="\t".join(line.split("\t")[:-1])+"\n"
                 file_handle_write.write(line)
 
-    utilities.run_task("remove_if_exists.py [args[0]] --is-folder ; picrust2_pipeline.py -s [args[1]] -i [args[2]] -o [args[0]] -p [args[3]]",
+    db_changes=""
+    if method == "its":
+        # change the databases to fungi
+        from picrust2.default import project_dir
+
+        trait_table = os.path.join(project_dir, "default_files","fungi","ec_ITS_counts.txt.gz")
+        reference_folder = os.path.join(project_dir, "default_files","fungi","fungi_ITS")
+        gene_table = os.path.join(project_dir, "default_files","fungi","ITS_counts.txt.gz")
+        pathway_map = os.path.join(project_dir, "default_files","pathway_mapfiles","metacyc_path2rxn_struc_filt_fungi_present.txt")
+
+        db_changes = " --custom_trait_tables {0} --min_reads 1 -r {1} --marker_gene_table {2} --pathway_map {3} --reaction_func {0} ".format(trait_table,reference_folder,gene_table,pathway_map)
+
+    utilities.run_task("remove_if_exists.py [args[0]] --is-folder ; picrust2_pipeline.py -s [args[1]] -i [args[2]] -o [args[0]] -p [args[3]] --stratified "+db_changes,
         depends=task.depends,
         targets=task.depends,
         args=[picrust2_output_dir, reformat_input_fasta, reformat_input_tsv, threads])
 
 
-def functional_profile(workflow, closed_reference_tsv, closed_reference_fasta, picrust_version, threads, output_folder, otus):
+def functional_profile(workflow, closed_reference_tsv, closed_reference_fasta, picrust_version, threads, output_folder, otus, method="16s"):
     """ Run picrust for functional profiling
     
     Args:
@@ -755,6 +773,7 @@ def functional_profile(workflow, closed_reference_tsv, closed_reference_fasta, p
         threads (int): The number of threads/cores for each task.
         output_folder (string): The path of the output folder.
         otus (bool): Are the inputs from OTUs (so all numerical ids).
+        method (string): Method used for data processing.
         
     Requires:
         Picrust v1.1 or v2: Software to predict metagenome function.
@@ -789,7 +808,7 @@ def functional_profile(workflow, closed_reference_tsv, closed_reference_fasta, p
         # run the v2 pipeline
         functional_data_predicted_tre = utilities.name_files("out.tre", output_folder, subfolder="picrust2")
         workflow.add_task(
-            utilities.partial_function(run_picrust2,threads=threads,otus=otus),
+            utilities.partial_function(run_picrust2,threads=threads,otus=otus,method=method),
             depends=[closed_reference_fasta, closed_reference_tsv],
             targets=functional_data_predicted_tre)
         return functional_data_predicted_tre
@@ -866,7 +885,31 @@ def convert_to_biom_from_tsv(workflow, tsv_file, biom_file, table_type="OTU tabl
         depends=[tsv_file,TrackedExecutable("biom")],
         targets=biom_file,
         name="biom")
+   
+def convert_from_biom_to_tsv_list(workflow, input_files, output):
+    # if any of the files provided are of type biom then convert to tsv
     
+    if isinstance(input_files, dict):
+        converted_files = {}
+    else:
+        converted_files = []
+
+    for filename in input_files:
+        if filename.endswith(".biom"):
+            new_tsv = utilities.name_files(filename.replace(".biom",".tsv"),output,subfolder="biom_to_tsv",create_folder=True)
+            convert_from_biom_to_tsv(workflow, filename, new_tsv)
+            if isinstance(input_files, dict):
+                converted_files[new_tsv] = input_files[filename] 
+            else:
+                converted_files.append(new_tsv)
+        else:
+            if isinstance(input_files, dict):
+                converted_files[filename] = input_files[filename]
+            else:
+                converted_files.append(filename)
+
+    return converted_files
+ 
 def convert_from_biom_to_tsv(workflow, biom_file, tsv_file, table_type="OTU table", options=""):
     """ Convert from a biom file to a tsv file 
     
