@@ -38,22 +38,23 @@ from biobakery_workflows import utilities, config
 # create a workflow instance, providing the version number and description
 # the version number will appear when running this script with the "--version" option
 # the description will appear when running this script with the "--help" option
-workflow = Workflow(version="0.1", description="A workflow for whole metagenome shotgun sequences")
+workflow = Workflow(version="3.1", description="A workflow for whole metagenome shotgun sequences")
 
 # add the custom arguments to the workflow
 workflow_config = config.ShotGun()
-workflow.add_argument("input-extension", desc="the input file extension", default="fastq.gz", choices=["fastq.gz","fastq","fq.gz","fq","fasta","fasta.gz","fastq.bz2","fq.bz2"])
+workflow.add_argument("input-extension", desc="the input file extension", default="fastq.gz", choices=["fastq.gz","fastq","fq.gz","fq","fasta","fasta.gz","fastq.bz2","fq.bz2","bam"])
 workflow.add_argument("barcode-file", desc="the barcode file", default="")
 workflow.add_argument("dual-barcode-file", desc="the string to identify the dual barcode file", default="")
 workflow.add_argument("index-identifier", desc="the string to identify the index files", default="_I1_001")
 workflow.add_argument("min-pred-qc-score", desc="the min phred quality score to use for demultiplexing", default=2)
 workflow.add_argument("threads", desc="number of threads/cores for each task to use", default=1)
-workflow.add_argument("pair-identifier", desc="the string to identify the first file in a pair", default=".R1")
+workflow.add_argument("pair-identifier", desc="the string to identify the first file in a pair, must proceed the file extension (ie R1_001.fastq.gz)", default=".R1")
 workflow.add_argument("interleaved", desc="indicates whether or not sequence files are interleaved", default=False, action="store_true")
 workflow.add_argument("bypass-quality-control", desc="do not run the quality control tasks", action="store_true")
 workflow.add_argument("contaminate-databases", desc="the path (or comma-delimited paths) to the contaminate\nreference databases for QC", 
     default=",".join([workflow_config.kneaddata_db_human_genome]))
 workflow.add_argument("qc-options", desc="additional options when running the QC step", default="")
+workflow.add_argument("qc-scratch", desc="scratch space to be used when running the QC step", default="")
 workflow.add_argument("functional-profiling-options", desc="additional options when running the functional profiling step", default="")
 workflow.add_argument("remove-intermediate-output", desc="remove intermediate output files", action="store_true")
 workflow.add_argument("bypass-functional-profiling", desc="do not run the functional profiling tasks", action="store_true")
@@ -62,6 +63,7 @@ workflow.add_argument("run-strain-gene-profiling", desc="run the gene-based stra
 workflow.add_argument("bypass-taxonomic-profiling", desc="do not run the taxonomic profiling tasks (a tsv profile for each sequence file must be included in the input folder using the same sample name)", action="store_true")
 workflow.add_argument("run-assembly", desc="run the assembly and annotation tasks", action="store_true")
 workflow.add_argument("strain-profiling-options", desc="additional options when running the strain profiling step", default="")
+workflow.add_argument("taxonomic-profiling-options", desc="additional options when running the taxonomic profiling step", default="")
 workflow.add_argument("max-strains", desc="the max number of strains to profile", default=20, type=int)
 workflow.add_argument("strain-list", desc="input file with list of strains to profile", default="")
 workflow.add_argument("assembly-options", desc="additional options when running the assembly step", default="")
@@ -117,7 +119,7 @@ if args.bypass_quality_control:
 elif not "fasta" in args.input_extension:
     qc_output_files, filtered_read_counts = shotgun.quality_control(workflow,
         demultiplexed_files, args.input_extension, args.output, args.threads, args.contaminate_databases,
-        args.pair_identifier, args.qc_options, args.remove_intermediate_output)
+        args.pair_identifier, args.qc_options, args.remove_intermediate_output, args.qc_scratch)
     # get the new extension, if the original files were gzipped they will not be after quality control
     args.input_extension = args.input_extension.replace(".gz","")
     args.input_extension = args.input_extension.replace(".bz2","")
@@ -128,9 +130,9 @@ else:
 ### STEP #2: Run taxonomic profiling on all of the filtered files ###
 if not args.bypass_taxonomic_profiling:
     merged_taxonomic_profile, taxonomy_tsv_files, taxonomy_sam_files = shotgun.taxonomic_profile(workflow,
-        qc_output_files,args.output,args.threads,args.input_extension)
+        qc_output_files,args.output,args.threads,args.input_extension, options=args.taxonomic_profiling_options)
 
-elif not args.bypass_functional_profiling or not args.bypass_strain_profiling:
+elif not args.bypass_functional_profiling or not args.bypass_strain_profiling or args.run_strain_gene_profiling:
     # get the names of the taxonomic profiling files allowing for pairs
     input_pair1, input_pair2 = utilities.paired_files(demultiplexed_files, original_extension, args.pair_identifier)
     sample_names = utilities.sample_names(input_pair1 if input_pair1 else input_files,original_extension,args.pair_identifier)
@@ -138,9 +140,9 @@ elif not args.bypass_functional_profiling or not args.bypass_strain_profiling:
     # check all of the expected profiles are found
     if len(tsv_profiles) != len(list(filter(os.path.isfile,tsv_profiles))):
         sys.exit("ERROR: Bypassing taxonomic profiling but all of the tsv taxonomy profile files are not found in the input folder. Expecting the following input files:\n"+"\n".join(tsv_profiles))
-    # run taxonomic profile steps bypassing metaphlan2
+    # run taxonomic profile steps bypassing metaphlan
     merged_taxonomic_profile, taxonomy_tsv_files, taxonomy_sam_files = shotgun.taxonomic_profile(workflow,
-        tsv_profiles,args.output,args.threads,"tsv",already_profiled=True)
+        tsv_profiles,args.output,args.threads,"tsv",already_profiled=True, options=args.taxonomic_profiling_options)
     # look for the sam profiles
     taxonomy_sam_files = utilities.name_files(sample_names, demultiplex_output_folder, tag="bowtie2", extension="sam")
     # if they do not all exist, then bypass strain profiling if not already set
@@ -158,16 +160,12 @@ if not args.bypass_functional_profiling:
 ### STEP #4: Run strain profiling
 # Provide taxonomic profiling output so top strains by abundance will be selected
 if not args.bypass_strain_profiling:
-    if args.bypass_taxonomic_profiling:
-        sys.exit("ERROR: Taxonomic profiling must be run to also run strain profiling")
     shotgun.strain_profile(workflow,taxonomy_sam_files,args.output,args.threads,
         workflow_config.strainphlan_db_reference,workflow_config.strainphlan_db_markers,merged_taxonomic_profile,
         args.strain_profiling_options,args.max_strains,args.strain_list)
 
 ### STEP #5: Run gene-based strain profiling (optional)
 if args.run_strain_gene_profiling:
-    if args.bypass_taxonomic_profiling and not args.strain_list:
-        sys.exit("ERROR: Taxonomic profiling must be run to also run gene-based strain profiling")
     if args.strain_list:
         merged_taxonomic_profile=args.strain_list
     shotgun.strain_gene_profile(workflow,qc_output_files,merged_taxonomic_profile,args.output,args.threads,workflow_config.panphlan_db,
